==> blesta-5.10.2.zip: blesta/language/sv_se/admin_company_groups.php <==
<?php
/**
 * Admin Company Groups
 *
 * @package blesta
 * @subpackage blesta.language.sv_se
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminCompanyGroups.edit.text_editsubmit'] = 'Redigera grupp';
$lang['AdminCompanyGroups.edit.field_force_email_usernames'] = 'Använd e-postadresser som användarnamn';
$lang['AdminCompanyGroups.edit.field_company_settings'] = 'Använd företagsinställningar (avmarkera för att ange nedan)';
$lang['AdminCompanyGroups.edit.field_delivery_methods'] = 'Metoder för leverans av fakturor';
$lang['AdminCompanyGroups.edit.field_description'] = 'Beskrivning';
$lang['AdminCompanyGroups.edit.field_color'] = 'Färg';
$lang['AdminCompanyGroups.edit.field_name'] = 'Namn';
$lang['AdminCompanyGroups.edit.heading_client_fields'] = 'Obligatoriska fält för kunden';
$lang['AdminCompanyGroups.edit.heading_client_settings'] = 'Allmänna klientinställningar';
$lang['AdminCompanyGroups.edit.heading_payment'] = 'Meddelanden';
$lang['AdminCompanyGroups.edit.heading_delivery'] = 'Leverans av fakturor';
$lang['AdminCompanyGroups.edit.heading_late_fees'] = 'Förseningsavgifter';
$lang['AdminCompanyGroups.edit.heading_invoice'] = 'Alternativ för fakturering och debitering';
$lang['AdminCompanyGroups.edit.heading_basic'] = 'Grundläggande alternativ';
$lang['AdminCompanyGroups.edit.boxtitle_editgroup'] = 'Redigera grupp';
$lang['AdminCompanyGroups.edit.page_title'] = 'Inställningar > Företag > Kundgrupper > Redigera grupp';
$lang['AdminCompanyGroups.add.text_addsubmit'] = 'Skapa grupp';
$lang['AdminCompanyGroups.add.field_email_verification'] = 'Aktivera e-postverifiering';
$lang['AdminCompanyGroups.add.field_force_email_usernames'] = 'Använd e-postadresser som användarnamn';
$lang['AdminCompanyGroups.add.field_company_settings'] = 'Använd företagsinställningar (avmarkera för att ange nedan)';
$lang['AdminCompanyGroups.add.field_delivery_methods'] = 'Metoder för leverans av fakturor';
$lang['AdminCompanyGroups.add.field_description'] = 'Beskrivning';
$lang['AdminCompanyGroups.add.field_color'] = 'Färg';
$lang['AdminCompanyGroups.add.field_name'] = 'Namn';
$lang['AdminCompanyGroups.add.heading_client_fields'] = 'Obligatoriska fält för kunden';
$lang['AdminCompanyGroups.add.heading_client_settings'] = 'Allmänna klientinställningar';
$lang['AdminCompanyGroups.add.heading_payment'] = 'Meddelanden';
$lang['AdminCompanyGroups.add.heading_delivery'] = 'Leverans av fakturor';
$lang['AdminCompanyGroups.add.heading_late_fees'] = 'Förseningsavgifter';
$lang['AdminCompanyGroups.add.heading_invoice'] = 'Alternativ för fakturering och debitering';
$lang['AdminCompanyGroups.add.heading_basic'] = 'Grundläggande alternativ';
$lang['AdminCompanyGroups.add.boxtitle_addgroup'] = 'Skapa grupp';
$lang['AdminCompanyGroups.add.page_title'] = 'Inställningar > Företag > Kundgrupper > Skapa grupp';
$lang['AdminCompanyGroups.index.confirm_delete'] = 'Är du säker på att du vill ta bort den här klientgruppen? Alla klienter i den här gruppen kommer att flyttas till standardgruppen.';
$lang['AdminCompanyGroups.index.no_results'] = 'Det finns inga kundgrupper.';
$lang['AdminCompanyGroups.index.option_delete'] = 'Radera';
$lang['AdminCompanyGroups.index.option_edit'] = 'Redigera';
$lang['AdminCompanyGroups.index.text_options'] = 'Alternativ';
$lang['AdminCompanyGroups.index.text_clients'] = 'Antal kunder';
$lang['AdminCompanyGroups.index.text_description'] = 'Beskrivning';
$lang['AdminCompanyGroups.index.text_name'] = 'Namn';
$lang['AdminCompanyGroups.index.categorylink_addgroup'] = 'Skapa grupp';
$lang['AdminCompanyGroups.index.boxtitle_groups'] = 'Kundgrupper';
$lang['AdminCompanyGroups.index.page_title'] = 'Inställningar > Företag > Kundgrupper';
$lang['AdminCompanyGroups.!tooltip.email_verification'] = 'Markera för att skicka ett e-postmeddelande om verifiering när en ny inloggning skapas eller en kund ändrar sin e-postadress. Ett meddelande kommer att visas på kundens profil tills de är verifierade.';
$lang['AdminCompanyGroups.!tooltip.force_email_usernames'] = 'Tar bort möjligheten för kunder att definiera sitt eget användarnamn.';
$lang['AdminCompanyGroups.!error.delete_failed'] = '%1$s är standardgruppen och kan inte tas bort.';
$lang['AdminCompanyGroups.!success.delete_deleted'] = '%1$s har raderats framgångsrikt!';
$lang['AdminCompanyGroups.!success.edit_updated'] = '%1$s har redigerats framgångsrikt!';
$lang['AdminCompanyGroups.!success.add_created'] = '%1$s har skapats framgångsrikt!';

==> blesta-5.11.4.zip: blesta/language/sv_se/admin_company_groups.php <==
<?php
/**
 * Admin Company Groups
 *
 * @package blesta
 * @subpackage blesta.language.sv_se
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminCompanyGroups.edit.text_editsubmit'] = 'Redigera grupp';
$lang['AdminCompanyGroups.edit.field_force_email_usernames'] = 'Använd e-postadresser som användarnamn';
$lang['AdminCompanyGroups.edit.field_company_settings'] = 'Använd företagsinställningar (avmarkera för att ange nedan)';
$lang['AdminCompanyGroups.edit.field_delivery_methods'] = 'Metoder för leverans av fakturor';
$lang['AdminCompanyGroups.edit.field_description'] = 'Beskrivning';
$lang['AdminCompanyGroups.edit.field_color'] = 'Färg';
$lang['AdminCompanyGroups.edit.field_name'] = 'Namn';
$lang['AdminCompanyGroups.edit.heading_client_fields'] = 'Obligatoriska fält för kunden';
$lang['AdminCompanyGroups.edit.heading_client_settings'] = 'Allmänna klientinställningar';
$lang['AdminCompanyGroups.edit.heading_payment'] = 'Meddelanden';
$lang['AdminCompanyGroups.edit.heading_delivery'] = 'Leverans av fakturor';
$lang['AdminCompanyGroups.edit.heading_late_fees'] = 'Förseningsavgifter';
$lang['AdminCompanyGroups.edit.heading_invoice'] = 'Alternativ för fakturering och debitering';
$lang['AdminCompanyGroups.edit.heading_basic'] = 'Grundläggande alternativ';
$lang['AdminCompanyGroups.edit.boxtitle_editgroup'] = 'Redigera grupp';
$lang['AdminCompanyGroups.edit.page_title'] = 'Inställningar > Företag > Kundgrupper > Redigera grupp';
$lang['AdminCompanyGroups.add.text_addsubmit'] = 'Skapa grupp';
$lang['AdminCompanyGroups.add.field_email_verification'] = 'Aktivera e-postverifiering';
$lang['AdminCompanyGroups.add.field_force_email_usernames'] = 'Använd e-postadresser som användarnamn';
$lang['AdminCompanyGroups.add.field_company_settings'] = 'Använd företagsinställningar (avmarkera för att ange nedan)';
$lang['AdminCompanyGroups.add.field_delivery_methods'] = 'Metoder för leverans av fakturor';
$lang['AdminCompanyGroups.add.field_description'] = 'Beskrivning';
$lang['AdminCompanyGroups.add.field_color'] = 'Färg';
$lang['AdminCompanyGroups.add.field_name'] = 'Namn';
$lang['AdminCompanyGroups.add.heading_client_fields'] = 'Obligatoriska fält för kunden';
$lang['AdminCompanyGroups.add.heading_client_settings'] = 'Allmänna klientinställningar';
$lang['AdminCompanyGroups.add.heading_payment'] = 'Meddelanden';
$lang['AdminCompanyGroups.add.heading_delivery'] = 'Leverans av fakturor';
$lang['AdminCompanyGroups.add.heading_late_fees'] = 'Förseningsavgifter';
$lang['AdminCompanyGroups.add.heading_invoice'] = 'Alternativ för fakturering och debitering';
$lang['AdminCompanyGroups.add.heading_basic'] = 'Grundläggande alternativ';
$lang['AdminCompanyGroups.add.boxtitle_addgroup'] = 'Skapa grupp';
$lang['AdminCompanyGroups.add.page_title'] = 'Inställningar > Företag > Kundgrupper > Skapa grupp';
$lang['AdminCompanyGroups.index.confirm_delete'] = 'Är du säker på att du vill ta bort den här klientgruppen? Alla klienter i den här gruppen kommer att flyttas till standardgruppen.';
$lang['AdminCompanyGroups.index.no_results'] = 'Det finns inga kundgrupper.';
$lang['AdminCompanyGroups.index.option_delete'] = 'Radera';
$lang['AdminCompanyGroups.index.option_edit'] = 'Redigera';
$lang['AdminCompanyGroups.index.text_options'] = 'Alternativ';
$lang['AdminCompanyGroups.index.text_clients'] = 'Antal kunder';
$lang['AdminCompanyGroups.index.text_description'] = 'Beskrivning';
$lang['AdminCompanyGroups.index.text_name'] = 'Namn';
$lang['AdminCompanyGroups.index.categorylink_addgroup'] = 'Skapa grupp';
$lang['AdminCompanyGroups.index.boxtitle_groups'] = 'Kundgrupper';
$lang['AdminCompanyGroups.index.page_title'] = 'Inställningar > Företag > Kundgrupper';
$lang['AdminCompanyGroups.!tooltip.email_verification'] = 'Markera för att skicka ett e-postmeddelande om verifiering när en ny inloggning skapas eller en kund ändrar sin e-postadress. Ett meddelande kommer att visas på kundens profil tills de är verifierade.';
$lang['AdminCompanyGroups.!tooltip.force_email_usernames'] = 'Tar bort möjligheten för kunder att definiera sitt eget användarnamn.';
$lang['AdminCompanyGroups.!error.delete_failed'] = '%1$s är standardgruppen och kan inte tas bort.';
$lang['AdminCompanyGroups.!success.delete_deleted'] = '%1$s har raderats framgångsrikt!';
$lang['AdminCompanyGroups.!success.edit_updated'] = '%1$s har redigerats framgångsrikt!';
$lang['AdminCompanyGroups.!success.add_created'] = '%1$s har skapats framgångsrikt!';
$lang['AdminCompanyGroups.edit.heading_gateway_restrictions'] = 'Tillåtna gateways';
$lang['AdminCompanyGroups.add.heading_gateway_restrictions'] = 'Tillåtna gateways';
